firewall {
    all-ping enable
    broadcast-ping disable
    group {
        network-group BOGONS {
            description "Invalid WAN networks"
            network 100.64.0.0/10
            network 127.0.0.0/8
            network 169.254.0.0/16
            network 172.16.0.0/12
            network 192.0.0.0/24
            network 192.0.2.0/24
            network 192.168.0.0/16
            network 198.18.0.0/15
            network 198.51.100.0/24
            network 203.0.113.0/24
            network 224.0.0.0/3
        }
    }
    ipv6-receive-redirects disable
    ipv6-src-route disable
    ip-src-route disable
    log-martians enable
    name GUEST_IN {
        default-action drop
        description "Internal network to Internet"
        rule 1 {
            action accept
            description HTTP
            destination {
                port 80
            }
            log disable
            protocol tcp_udp
        }
        rule 2 {
            action accept
            description HTTPS
            destination {
                port 443
            }
            log disable
            protocol tcp_udp
        }
        rule 3 {
            action accept
            description IMAP
            destination {
                port 143
            }
            log disable
            protocol tcp_udp
        }
        rule 4 {
            action accept
            description IMAP/S
            destination {
                port 993
            }
            log disable
            protocol tcp_udp
        }
        rule 5 {
            action accept
            description SMTP/S
            destination {
                port 465,587
            }
            log disable
            protocol tcp_udp
        }
        rule 6 {
            action accept
            description NTP
            destination {
                port ntp
            }
            log disable
            protocol udp
        }
    }
    name GUEST_LOCAL {
        default-action accept
        description "Internal network to router"
    }
    name LAN_IN {
        default-action accept
        description "Internal network to Internet"
    }
    name LAN_LOCAL {
        default-action accept
        description "Internal network to router"
    }
    name WAN_IN {
        default-action drop
        description "Internet to internal networks"
        enable-default-log
        rule 1 {
            action accept
            description "allow established/related"
            log disable
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action drop
            log enable
            state {
                invalid enable
            }
        }
        rule 3 {
            action drop
            description "drop BOGON source"
            log enable
            protocol all
            source {
                group {
                    network-group BOGONS
                }
            }
        }
    }
    name WAN_LOCAL {
        default-action drop
        description "Internet to router"
        enable-default-log
        rule 1 {
            action accept
            description "allow established/related"
            log disable
            state {
                established enable
                related enable
            }
        }
        rule 2 {
            action accept
            description "Remote GUI to router"
            destination {
                port 443
            }
            log enable
            protocol tcp
        }
        rule 4 {
            action drop
            description "drop invalid"
            log enable
            state {
                invalid enable
            }
        }
        rule 5 {
            action drop
            description "drop BOGON source"
            log enable
            protocol all
            source {
                group {
                    network-group BOGONS
                }
            }
        }
        rule 6 {
            action accept
            description "rate limit ICMP 50/m"
            limit {
                burst 1
                rate 50/minute
            }
            log enable
            protocol icmp
        }
    }
    receive-redirects disable
    send-redirects enable
    source-validation disable
    syn-cookies enable
}
interfaces {
    ethernet eth0 {
        duplex auto
        speed auto
    }
    ethernet eth1 {
        duplex auto
        speed auto
    }
    ethernet eth2 {
        address dhcp
        description WAN
        duplex auto
        firewall {
            in {
                name WAN_IN
            }
            local {
                name WAN_LOCAL
            }
        }
        speed auto
    }
    loopback lo {
    }
}
port-forward {
    auto-firewall enable
    hairpin-nat enable
    lan-interface br0
    wan-interface eth2
}
service {
    dhcp-server {
        disabled false
        hostfile-update disable
        shared-network-name GUEST-br0 {
            authoritative disable
            subnet 192.168.20.0/24 {
                default-router 192.168.20.1
                dns-server 192.168.20.1
                lease 86400
                start 192.168.20.100 {
                    stop 192.168.20.199
                }
            }
        }
        shared-network-name LAN-br0 {
            authoritative disable
            description "LAN Network - br0"
            subnet 192.168.1.0/24 {
                default-router 192.168.1.1
                dns-server 192.168.1.1
                lease 86400
                ntp-server 192.168.1.1
                start 192.168.1.100 {
                    stop 192.168.1.199
                }
                time-server 192.168.1.1
            }
        }
    }
    dns {
        forwarding {
            cache-size 150
            listen-on br0
            listen-on br0.20
            system
        }
    }
    gui {
        https-port 443
        listen-address 192.168.1.1
        listen-address 172.168.1.147
    }
    nat {
        rule 5010 {
            description "WAN MASQ"
            log disable
            outbound-interface eth2
            protocol all
            type masquerade
        }
    }
    ssh {
        port 22
        protocol-version v2
    }
    upnp {
        listen-on br0 {
            outbound-interface eth2
        }
    }
}
system {
    config-management {
        commit-archive {
        }
        commit-revisions 50
    }
    conntrack {
        expect-table-size 4096
        hash-size 4096
        table-size 32768
        tcp {
            half-open-connections 512
            loose enable
            max-retrans 3
        }
    }
    gateway-address 172.168.1.1
    host-name Cerberus
    ipv6 {
        disable
    }
    login {
        banner {
            post-login "Welcome to EdgeMAX"
            pre-login "\n\n\t UNAUTHORIZED USE OF THE SYSTEM\n\n\t IS PROHIBITED! \n\n "
        }
        user jeroen {
            authentication {
                encrypted-password $6$cyteUF69$d7KAggav/2eOOIuKIrR0Uij1h4wP3oi/2MQ8eHhdfjZJFYz7zTEiRFohN9h8MPJzOWz1mUY2P.llxjNBZyodZ1
                plaintext-password ""
            }
            full-name jeroen
            level admin
        }
        user tweakers-admin {
            authentication {
                encrypted-password $6$Uq8RhipW.Hp$fFR/Y5Oh3squuCuuyS8tEuFLeKYsehTyw2fuNzqbLEVByiG4sPtDTFlsbQBoBtvxH95CaTYTyYXruvzSMi2Pj/
                plaintext-password ""
            }
            level admin
        }
        user tweakers-operator {
            authentication {
                encrypted-password $6$SOk9MB1PsUC$9CbKoDj8xOl6eokDACWDB4EV1qbJ0LXSWxzdTnhfVRv7.8dGGe08Uw/BrNbAF/PJvtg5uTKkZsJNxrivRPpEL1
                plaintext-password ""
            }
            level operator
        }
    }
    name-server 172.168.1.1
    ntp {
        server 0.ubnt.pool.ntp.org {
        }
        server 1.ubnt.pool.ntp.org {
        }
        server 2.ubnt.pool.ntp.org {
        }
        server 3.ubnt.pool.ntp.org {
        }
    }
    offload {
        ipsec enable
        ipv4 {
            forwarding enable
            pppoe enable
            vlan disable
        }
        ipv6 {
            forwarding enable
            pppoe enable
            vlan disable
        }
    }
    package {
        repository squeeze {
            components "main contrib non-free"
            distribution squeeze
            password ""
            url http://ftp.us.debian.org/debian/
            username ""
        }
        repository squeeze-updates {
            components "main contrib"
            distribution squeeze/updates
            password ""
            url http://security.debian.org/
            username ""
        }
    }
    syslog {
        global {
            facility all {
                level notice
            }
            facility protocols {
                level debug
            }
        }
    }
    task-scheduler {
    }
    time-zone Europe/Amsterdam
}


/* Warning: Do not remove the following line. */
/* === vyatta-config-version: "config-management@1:conntrack@1:cron@1:dhcp-relay@1:dhcp-server@4:firewall@5:ipsec@4:nat@3:qos@1:quagga@2:system@4:ubnt-pptp@1:ubnt-util@1:vrrp@1:webgui@1:webproxy@1:zone-policy@1" === */
/* Release version: v1.7.0alpha3.4760682.150404.2033 */
